/* Functions that provide the mechanism to parse a syscall XML file
   and get its values.

   Copyright (C) 1986, 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996,
   1998, 1999, 2000, 2001, 2003, 2004, 2005, 2006, 2007, 2008
   Free Software Foundation, Inc.

   This file is part of GDB.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#ifndef XML_SYSCALL_H
#define XML_SYSCALL_H 1

/* Structure that stores information about the system's
   syscalls.  */

struct syscalls_info;


/* Function responsible for initializing the information
   about the syscalls.  It reads the XML file and fills the
   struct syscalls_info with the values.
   
   Returns the struct syscalls_info if the file is valid, NULL otherwise.  */

const struct syscalls_info *xml_init_syscalls_info (const char *);

/* Function that retrieves the syscall number corresponding to the given
   name.

   Returns the syscall number if found, or  otherwise.  */

int xml_get_syscall_number (const struct syscalls_info *, const char *);

/* Function that retrieves the syscall name corresponding to the given
   number.

   Returns the syscall name if found, NULL otherwise.  */
const char *xml_get_syscall_name (const struct syscalls_info *, int);

/* Function that returns the number of syscalls defined in the system.

   Returns the number of syscalls, or zero otherwise.  */
int xml_number_of_syscalls (const struct syscalls_info *);

/* Function used to retrieve the list of syscalls in the system.  This list
   is returned as an array of strings.

   Returns the list of syscalls in the system, or NULL otherwise.  */
const char **xml_list_of_syscalls (const struct syscalls_info *sysinfo);

#endif /* XML_SYSCALL_H */
